summaryrefslogtreecommitdiffstats
path: root/kexi/main/ksplitter.h
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/main/ksplitter.h')
-rw-r--r--kexi/main/ksplitter.h47
1 files changed, 24 insertions, 23 deletions
diff --git a/kexi/main/ksplitter.h b/kexi/main/ksplitter.h
index db72ec880..9bf359b17 100644
--- a/kexi/main/ksplitter.h
+++ b/kexi/main/ksplitter.h
@@ -18,14 +18,14 @@
*/
/*
- IMPORTANT Note: This file compiles also in Qt-only mode by using the NO_KDE2 precompiler definition
+ IMPORTANT Note: This file compiles also in TQt-only mode by using the NO_KDE2 precompiler definition
*/
#ifndef KDOCKWIDGET_PRIVATE_H
#define KDOCKWIDGET_PRIVATE_H
-#include <qwidget.h>
-#include <qpushbutton.h>
+#include <tqwidget.h>
+#include <tqpushbutton.h>
#include <kdeversion.h>
@@ -33,29 +33,30 @@
#include <netwm_def.h>
#endif
-class QFrame;
+class TQFrame;
class KDockContainer;
class KDockWidget;
/**
- * Like QSplitter but specially designed for dockwidgets stuff.
+ * Like TQSplitter but specially designed for dockwidgets stuff.
* @internal
*
* @author Max Judin.
*/
-class KDockSplitter : public QWidget
+class KDockSplitter : public TQWidget
{
//Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent parent widget
* @param name name
- * @param orient orientation. Either @p Vertical or @p Horizontal
+ * @param orient orientation. Either @pQt::Vertical or @pQt::Horizontal
* @param pos procentual position of the splitter. Must be int [0...100].
*/
- KDockSplitter(QWidget *parent= 0, const char *name= 0, Orientation orient= Vertical, int pos= 50);
+ KDockSplitter(TQWidget *tqparent= 0, const char *name= 0, Qt::Orientation orient=Qt::Vertical, int pos= 50);
virtual ~KDockSplitter(){};
/**
@@ -66,7 +67,7 @@ public:
* @param c0 the widget on top/left
* @param c1 the widget on borrom/right
*/
- void activate(QWidget *c0, QWidget *c1 = 0L);
+ void activate(TQWidget *c0, TQWidget *c1 = 0L);
/**
* Disables the splitter.
*/
@@ -129,22 +130,22 @@ public:
* The eventfilter installed on the @p divider processes
* all splitter resizing events.
*/
- virtual bool eventFilter(QObject *, QEvent *);
- virtual bool event( QEvent * );
+ virtual bool eventFilter(TQObject *, TQEvent *);
+ virtual bool event( TQEvent * );
/**
* @return the top/left child widget.
*/
- QWidget* getFirst() const { return child0; }
+ TQWidget* getFirst() const { return child0; }
/**
* @return the bottom/right child widget.
*/
- QWidget* getLast() const { return child1; }
+ TQWidget* getLast() const { return child1; }
/**
* If @p w is child0, return child1, otherwise child0.
* @return the other child widget
*/
- QWidget* getAnother( QWidget* w ) const;
+ TQWidget* getAnother( TQWidget* w ) const;
void updateName();
/**
@@ -168,9 +169,9 @@ public:
void restoreFromForcedFixedSize(KDockWidget *dw);
/**
- * The orientation is either @p Horizontal or @p Vertical.
+ * The orientation is either @pQt::Horizontal or @pQt::Vertical.
*/
- Orientation orientation(){return m_orientation;}
+ Qt::Orientation orientation(){return m_orientation;}
protected:
friend class KDockContainer;
@@ -187,7 +188,7 @@ protected:
* @param child the overlapping child
* @return the (new) splitter position.
*/
- int checkValueOverlapped(int position, QWidget* child) const;
+ int checkValueOverlapped(int position, TQWidget* child) const;
/**
* The resize event resizes @p child0, @p child1 and the @p divider.
@@ -203,7 +204,7 @@ protected:
* @param ev the resize Event. If @p ev=0L the user changed
* the mode (for example from overlap to nonoverlap mode).
*/
- virtual void resizeEvent(QResizeEvent *ev);
+ virtual void resizeEvent(TQResizeEvent *ev);
/*
protected slots:
@@ -221,8 +222,8 @@ private:
* so no need to make pointer checks.
* child[01]->getWidget() may be KDockContainer.
*/
- QWidget *child0, *child1;
- Orientation m_orientation;
+ TQWidget *child0, *child1;
+ Qt::Orientation m_orientation;
/**
* If initialised is true, the divider!=0L. If false, the divider==0L!
*/
@@ -231,10 +232,10 @@ private:
* The splitter controller which is between child0 and child1.
* Its size is 4 pixel.
*/
- QFrame* divider;
+ TQFrame* divider;
/**
* @p xpos and @p savedXPos represent the current divider position.
- * If the orientation is Horizontal @p xpos actually is "ypos". So
+ * If the orientation isQt::Horizontal @p xpos actually is "ypos". So
* do not get confused only because of the 'x'.
*
* xpos and savedXPos are internally high resolution. So *not* 0..100%
@@ -33,29 +33,30 @@
/**
* Constructor.
- * @param parent parent widget
+ * @param tqparent tqparent widget
* @param name name